# Roshi
Roshi - The Manga Scraper

Note: I do not own any of the work that is being downloaded. Each series belongs to the respective manga artist. Please buy the volumes after they have been released.
